Turns and Angular Analysis
==========================

Turns
-----

Turns can be calculated using :func:`~traja.trajectory.calc_angle`.

.. autofunction:: traja.trajectory.calc_angle

Heading
-------

Heading can be calculated using :func:`~traja.trajectory.calc_heading`.

.. autofunction:: traja.trajectory.calc_heading

Angles
------

Angles can be calculated using :func:`~traja.trajectory.angles`.

.. autofunction:: traja.trajectory.angles

